[![Documentation Status](https://readthedocs.org/projects/pybia/badge/?version=latest)](https://pybia.readthedocs.io/en/latest/?badge=latest)
[![GPLv3 License](https://img.shields.io/badge/License-GPL%20v3-yellow.svg)](https://opensource.org/licenses/LGPL-3.0)
[![TensorFlow](https://img.shields.io/badge/TensorFlow-2.6-orange.svg)](https://tensorflow.org)

# pyBIA

A machine learning classifier for detecting Lyman-alpha blobs in wide-field surveys.

# Installation

```
    $ pip install pyBIA
```

# [Documentation](https://pybia.readthedocs.io/en/latest/)

For technical details and an example of how to implement pyBIA for a lyman-alpha blob search, check out our [Documentation](https://pybia.readthedocs.io/en/latest/).


# How to Contribute?

Want to contribute? Bug detections? Comments? Suggestions? Please email us : danielgodinez123@gmail.com, mkpresco@nmsu.edu
